# Changelog
All notable changes in **django-sms** are documented below.

## [Unreleased]

## [0.2.0] (2021-01-21)
### Added
- The file backend that writes text messages to a file ([#1](https://github.com/roaldnefs/django-sms/pull/1)).

## [0.1.0] (2021-01-15)
### Added
- This `CHANGELOG.md` file to be able to list all notable changes for each version of **django-sms**.

[Unreleased]: https://github.com/roaldnefs/django-sms/compare/v0.2.0...HEAD
[0.2.0]: https://github.com/roaldnefs/django-sms/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/roaldnefs/django-sms/releases/tag/v0.1.0
